@@ -1,10 +1,10 @@
 """
 @author: Roman Matusevich
 """
-import binascii
+import base64
 
 import rlp
-from mintersdk import MinterConvertor
+from mintersdk import MinterHelper
 
 
 class MinterDeeplink(object):
@@ -16,7 +16,7 @@ class MinterDeeplink(object):
         """
         Create deeplink object
         Args:
-            tx (object): MinterTx object
+            tx (MinterTx): MinterTx object
             data_only (bool): Generate deeplink only with tx data
             base_url (str): Base URL for generated deeplink
         """
@@ -48,22 +48,26 @@ class MinterDeeplink(object):
         """
 
         # Create deeplink structure
-        gas_coin = MinterConvertor.encode_coin_name(
+        gas_coin = MinterHelper.encode_coin_name(
             self.gas_coin
         ) if self.gas_coin else ''
         deep_structure = [self.__type, self.__data, self.payload, self.nonce,
                           self.gas_price, gas_coin]
 
-        # Create deeplink hash (`d` URL param)
+        # Create deephash base64 urlsafe
         deephash = rlp.encode(deep_structure)
-        deephash = binascii.hexlify(deephash).decode()
+        deephash = base64.urlsafe_b64encode(deephash)
+        deephash = deephash.decode().rstrip('=')
 
         # Create deeplink URL
-        deeplink = self.base_url + '?d=' + deephash
+        deeplink = self.base_url + '/' + deephash
 
         # If password check needed, add (`p` URL param)
         if password:
-            password = binascii.hexlify(rlp.encode(password)).decode()
-            deeplink += '&p=' + password
+            password = password.encode().hex()
+            password = base64.urlsafe_b64encode(password.encode())
+            password = password.decode().rstrip('=')
+
+            deeplink += '?p=' + password
 
         return deeplink
